==> treelib_1.7.1.orig.tar.xz: treelib-1.7.1/README.md <==
# treelib

Tree implementation in python: simple for you to use.

[![Build Status](https://github.com/caesar0301/treelib/actions/workflows/python-package.yml/badge.svg)](https://github.com/caesar0301/treelib/actions)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Documentation Status](https://readthedocs.org/projects/treelib/badge/?version=latest)](http://treelib.readthedocs.io/en/latest/?badge=latest)
[![Status](https://img.shields.io/pypi/status/treelib.svg)](https://pypi.python.org/pypi/treelib)
[![Latest](https://img.shields.io/pypi/v/treelib.svg)](https://pypi.python.org/pypi/treelib)
[![PyV](https://img.shields.io/pypi/pyversions/treelib.svg)](https://pypi.python.org/pypi/treelib)
[![PyPI download month](https://img.shields.io/pypi/dm/treelib.svg)](https://pypi.python.org/pypi/treelib/)
[![GitHub contributors](https://img.shields.io/github/contributors/caesar0301/treelib.svg)](https://GitHub.com/caesar0301/treelib/graphs/contributors/)

[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square)](http://makeapullrequest.com)
[![GitHub pull-requests](https://img.shields.io/github/issues-pr/caesar0301/treelib.svg)](https://GitHub.com/caesar0301/treelib/pulls)
[![GitHub pull-requests closed](https://img.shields.io/github/issues-pr-closed/caesar0301/treelib.svg)](https://GitHub.com/caesar0301/treelib/pulls?q=is%3Apr+is%3Aclosed)

## Quick Start

    pip install -U treelib

## Documentation

For installation, APIs and examples, see http://treelib.readthedocs.io/en/latest/

## Code Style

`treelib` complies with [black](https://github.com/psf/black) formatter and
specific [flake8 validations](https://github.com/caesar0301/treelib/blob/master/scripts/flake8.sh).
Before creating a pull request, please make sure you pass the local validation
with `scripts/flake8.sh`.

## Contributors

Thank you all,
[committers](https://github.com/caesar0301/treelib/graphs/contributors).

==> treelib_1.8.0.orig.tar.xz: treelib-1.8.0/README.md <==
# treelib

Tree implementation in python: simple for you to use.

[![Build Status](https://github.com/caesar0301/treelib/actions/workflows/python-package.yml/badge.svg)](https://github.com/caesar0301/treelib/actions)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Documentation Status](https://readthedocs.org/projects/treelib/badge/?version=latest)](http://treelib.readthedocs.io/en/latest/?badge=latest)
[![Status](https://img.shields.io/pypi/status/treelib.svg)](https://pypi.python.org/pypi/treelib)
[![Latest](https://img.shields.io/pypi/v/treelib.svg)](https://pypi.python.org/pypi/treelib)
[![PyV](https://img.shields.io/pypi/pyversions/treelib.svg)](https://pypi.python.org/pypi/treelib)
[![PyPI download month](https://img.shields.io/pypi/dm/treelib.svg)](https://pypi.python.org/pypi/treelib/)
[![GitHub contributors](https://img.shields.io/github/contributors/caesar0301/treelib.svg)](https://GitHub.com/caesar0301/treelib/graphs/contributors/)

[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square)](http://makeapullrequest.com)
[![GitHub pull-requests](https://img.shields.io/github/issues-pr/caesar0301/treelib.svg)](https://GitHub.com/caesar0301/treelib/pulls)
[![GitHub pull-requests closed](https://img.shields.io/github/issues-pr-closed/caesar0301/treelib.svg)](https://GitHub.com/caesar0301/treelib/pulls?q=is%3Apr+is%3Aclosed)


## Quick Start

    pip install -U treelib

## Documentation

For installation, APIs and examples, see http://treelib.readthedocs.io/en/latest/

Ask DeepWiki: https://deepwiki.com/caesar0301/treelib

### Development Commands

We provide a convenient Makefile for common development tasks. Run `make help` to show usage.

Before creating a pull request, please make sure you pass the local validation
with `make check`.

## Contributors

Thank you all contributors ❤

[![treelib contributors](https://contrib.rocks/image?repo=caesar0301/treelib "treelib contributors")](https://github.com/caesar0301/treelib/graphs/contributors)
